class Ply:
    """
    Defines the properties of a ply (laminae) within a laminate.

    The properties of a ply are:
    e: the elastic modulus
    g: the shear modulus
    t: the thickness
    """
    def __init__(self):
        self.e = 0
        self.g = 0
        self.t = 0

    def __repr__(self):
        return "E={},\tG={},\tt={}".format(self.e, self.g, self.t)


class _Lamina(Ply):
    """
    A sub-class of Ply that is used internally. Several other member variables are included in this sub-class:

    e: the elastic modulus
    g: the shear modulus
    t: the thickness
    z: the elevation of the center of the ply
    zeta_center: the elevation of the center of the ply with respect to the neutral axis
    zeta_bot: the elevation of the bottom of the ply with respect to the neutral axis
    zeta_top: the elevation of the top of the ply with respect to the neutral axis
    a_0: the value of A_{Ck}, as defined in the present model
    a_2: the value of A_{2k}, as defined in the present model
    d_0: the value of D_{Ck}, as defined in the present model
    d_1: the value of D_{1k}, as defined in the present model
    d_3: the value of D_{3k}, as defined in the present model
    """
    def __init__(self, ply: Ply):
        super().__init__()
        self.e = ply.e
        self.g = ply.g
        self.t = ply.t
        self.z = 0
        self.zeta_center = 0
        self.zeta_bot = 0
        self.zeta_top = 0
        self.z_ref_mid_bot = 0
        self.z_ref_mid_top = 0
        self.a_0 = 0
        self.a_2 = 0
        self.d_0 = 0
        self.d_1 = 0
        self.d_3 = 0

    def __repr__(self):
        return "E={}\tG={}\tt={}\tz={}\tz_bot_na={}".format(self.e, self.g, self.t, self.z, self.zeta_bot)
