from unittest import TestCase
import Beam


class TestLaminate(TestCase):
    def test_update_na_height(self):
        aluminum = Beam.Ply()
        aluminum.e = 73e9
        aluminum.g = 28e9
        aluminum.t = 10

        lam = Beam.Laminate()
        lam.width = 20
        lam.plies = [aluminum, aluminum]

        self.assertAlmostEqual(lam.plies[0].z, 5)
        self.assertAlmostEqual(lam.plies[1].z, 15)
        self.assertAlmostEqual(lam.plies[0].zeta_center, -5)
        self.assertAlmostEqual(lam.plies[1].zeta_center, 5)

        soft = Beam.Ply()
        soft.e = 0
        soft.g = 1  # cannot be zero
        soft.t = 100
        lam.plies = [aluminum, soft, aluminum]
        self.assertAlmostEqual(lam.plies[0].z, 5)
        self.assertAlmostEqual(lam.plies[1].z, 60)
        self.assertAlmostEqual(lam.plies[2].z, 115)
        self.assertAlmostEqual(lam.plies[0].zeta_center, -55)
        self.assertAlmostEqual(lam.plies[1].zeta_center, 0)
        self.assertAlmostEqual(lam.plies[2].zeta_center, 55)

    def test_calc_ei(self):
        aluminum = Beam.Ply()
        aluminum.e = 73e9
        aluminum.g = 28e9
        aluminum.t = 10

        lam = Beam.Laminate()
        lam.width = 20

        lam.plies = [aluminum]
        self.assertAlmostEqual(lam.calc_ei(), 1 / 12 * aluminum.e * lam.width * aluminum.t ** 3)

        lam.plies = [aluminum, aluminum]
        self.assertAlmostEqual(lam.calc_ei(), 1 / 12 * aluminum.e * lam.width * (aluminum.t * 2) ** 3)

        lam.plies = [aluminum, aluminum, aluminum]
        # the value of EI is quite large (3e+15), an error on the order of 1.0 is acceptable
        self.assertAlmostEqual(lam.calc_ei(), 1 / 12 * aluminum.e * lam.width * (aluminum.t * 3) ** 3, places=0)

        soft = Beam.Ply()
        soft.e = 0
        soft.g = 1  # cannot be zero
        soft.t = 100
        lam.plies = [aluminum, soft, aluminum]
        self.assertAlmostEqual(lam.calc_ei(), 2 / 12 * aluminum.e * lam.width * aluminum.t ** 3 +
                               2 * aluminum.e * lam.width * aluminum.t * (aluminum.t / 2 + soft.t / 2) ** 2)
